<!-- connection -->
<!-- GetButton.io widget
<script type="text/javascript">
    (function () {
        var options = {
            whatsapp: "+1 7274286335", // WhatsApp number
            call_to_action: "Message us", // Call to action
            position: "left", // Position may be 'right' or 'left'
        };
        var proto = document.location.protocol, host = "getbutton.io", url = proto + "//static." + host;
        var s = document.createElement('script'); s.type = 'text/javascript'; s.async = true; s.src = url + '/widget-send-button/js/init.js';
        s.onload = function () { WhWidgetSendButton.init(host, proto, options); };
        var x = document.getElementsByTagName('script')[0]; x.parentNode.insertBefore(s, x);
    })();
</script>
connection -->


<!-- header -->

<!DOCTYPE html>
<html>

<meta http-equiv="content-type" content="text/html;charset=UTF-8" /><!-- /Added by HTTrack -->
<meta http-equiv="content-type" content="text/html;charset=UTF-8" />
<head>
	<!-- Required meta tags -->
    <meta charset="utf-8"><link rel="stylesheet" href="stackpath.bootstrapcdn.com/bootstrap/4.3.1/css/bootstrap.min.css">
    <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1,shrink-to-fit=no, user-scalable=0"/> <!--320-->

    <link rel="stylesheet" href="stackpath.bootstrapcdn.com/bootstrap/4.3.1/css/bootstrap.min.css">

    <!-- link to stylesheet -->
    <link rel="stylesheet" type="text/css" href="css/style.css">
    <link rel="stylesheet" type="text/css" href="css/style_preloader.css">

    <link href="https://fonts.googleapis.com/css?family=Raleway&amp;display=swap" rel="stylesheet">

    <link rel="stylesheet" href="css/jquery-ui.css">

    <script src="js/jquery-ui.js"></script>


    <!-- linkig for fontawesome styling -->
    <script src="kit.fontawesome.com/e44d5a293a.js" crossorigin="anonymous"></script> <!--load all styles -->


	<title>Alpha Chequers™ | Mining analysis</title>

	<script type="text/javascript" src="js/jquery-3.2.1.min.js"></script>

	<!-- including script for sweet.js -->
    <script src="js/sweetalert.min.js"></script>

    <!-- // Add the new slick-theme.css if you want the default styling -->
	<link rel="stylesheet" type="text/css" href="slick/slick-theme.css"/>
	<link rel="stylesheet" type="text/css" href="slick/slick.css"/>

    <!-- including the frank font cdn -->
    <link href="http://db.onlinewebfonts.com/c/15a9075ddf4ff1158eb03abbc873a3a4?family=Frank-Light" rel="stylesheet" type="text/css"/> 

 
	 <!-- scripy for cycle -->
    <script src="js/jquery.cycle.all.js"></script>





    <script type="text/javascript">
      jQuery(window).on("load", function () {
        $('#preloader').fadeOut(500);
        $('#main-wrapper').addClass('show');
    });
    </script>
	
	<!-- favicon -->
  <link href="images/myfavicon.png" rel="icon" type="image/x-icon">	

  <style>
    #preloader {
    position: fixed;
    width: 100%;
    height: 100%;
    left: 0;
    top: 0;
    background-color: #000;
    z-index: 999999999; }
  
  .sk-three-bounce {
    margin: 0;
    width: 100%;
    height: 100%;
    text-align: center;
    background-color: #000; }
  
  .sk-three-bounce .sk-child {
    position: relative;
    top: 50%;
    transform: translateY(-50%);
    width: 20px;
    height: 20px;
    background-color: #007bff;
    border-radius: 100%;
    display: inline-block;
    -webkit-animation: sk-three-bounce 1.4s ease-in-out 0s infinite both;
    animation: sk-three-bounce 1.4s ease-in-out 0s infinite both; }
  
  .sk-three-bounce .sk-bounce1 {
    -webkit-animation-delay: -0.32s;
    animation-delay: -0.32s; }
  
  .sk-three-bounce .sk-bounce2 {
    -webkit-animation-delay: -0.16s;
    animation-delay: -0.16s; }
  
  @-webkit-keyframes sk-three-bounce {
    0%,
    80%,
    100% {
      -webkit-transform: scale(0);
      transform: scale(0); }
    40% {
      -webkit-transform: scale(1);
      transform: scale(1); } }
  
  @keyframes sk-three-bounce {
    0%,
    80%,
    100% {
      -webkit-transform: scale(0);
      transform: scale(0); }
    40% {
      -webkit-transform: scale(1);
      transform: scale(1); } 
    }
  </style>
</head><!-- header -->

<body>
	<!-- this is the preloader section  -->
	<div id="preloader">
    <div class="sk-three-bounce">
        <div class="sk-child sk-bounce1"></div>
        <div class="sk-child sk-bounce2"></div>
        <div class="sk-child sk-bounce3"></div>
    </div>
</div>
	<!-- preloader section ends here -->
	

	<!-- main body wrapper design starts here  -->
	<section class="wrapper container-fluid">

		 <!-- ----------------------First section with the animination main-bg--------------------------- -->
    <section>
       
		<!-- Start of the first nav -->
		<div class="container-fluid col-f-nav">
			<div class="container">
				<div class="row"> 
					<!-- this is the logo section  -->
					<div class="col-md-3 col-sm-12" style="margin-top: 20px !important">
            <a class="navbar-brand" href="index.php" style="color:#007bff; font-family: 'Trebuchet MS', sans-serif; font-size: 19px;"> <img src="images/mylogo.png" style="height: 30px; width: 30px" class="brand">&nbsp;ALPHA <span style="color: orange">CHEQUERS<span style="color: #fff; font-family:Arial !important;">™</span></span></a>
						<button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
						    <img src="images/icon/hamburger-blk.png">
						  </button>

					</div>

					<!-- ==================================================================================================== -->

					<div class="col-md-5 col-sm-12 nav">
						<nav class="navbar navbar-expand-lg navbar-light">
							
										 
						  <div class="collapse navbar-collapse" id="navbarSupportedContent">
						    <ul class="navbar-nav mr-auto" style="font-size: 11px !important;">
                                <li class="nav-item"><a class="nav-link" href="index.php">HOME</a></li>

						      	<li class="nav-item dropdown">
						        <a class="nav-link dropdown-toggle" href="#" id="navbarDropdown" role="button" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
						          MARKETS 
						        </a>

                                <div class="dropdown-menu dropdown-menu-right animate slideIn" aria-labelledby="navbarDropdown">
						          <a class="dropdown-item" href="crypto.php"> <i class="fas fa-angle-right drop-icon-left"></i>  CRYPTOS</a>
						          <a class="dropdown-item" href="indices.php"> <i class="fas fa-angle-right drop-icon-left"></i>  INDICIES</a>						      
						          <a class="dropdown-item" href="shares.php"> <i class="fas fa-angle-right drop-icon-left"></i>  SHARES</a>
                                 <a class="dropdown-item" href="commodities.php"> <i class="fas fa-angle-right drop-icon-left"></i>  COMMODITIES</a>						          
						        </div>

						      </li>
						      
						       <li class="nav-item">
						        <a class="nav-link" href="Mining_operation.php">MINING OPERATIONS</a>
						      </li>

						      <li class="nav-item">
						        <a class="nav-link" href="about.php">ABOUT US</a>
						      </li>	

						      <li class="nav-item">
						        <a class="nav-link" href="faq.php">FAQS</a>
						      </li>

						      <li class="nav-item">
						        <a class="nav-link" href="contact.php">CONTACTS</a> 
						      </li>
						      
						      <li class="nav-item">
						        <a class="nav-link" href="live-trade.php">TRADE</a>
						      </li>
						      
						      <li class="nav-item">
						        <a class="nav-link" href="Account/Signin/access-login.php">LOGIN</a>
						      </li>
						      
						    </ul>
						  </div>
						</nav>
					</div>


					<!-- this is the other side that contains signup and the rest  -->

					<!-- =================================================================================== -->


					<div class="col-md-4 col-sm-12 top-contact-wrap">
													

                    <a href="Account/Signup/client-register.php" class="top-signup float-right" style="background: #007bff !important; font-family:'Arial Narrow', Arial, sans-serif;"> Signup </a>
							<a href="Account/Signin/index.html" class="top-login float-right display-none-mobile" style="font-family:'Arial Narrow', Arial, sans-serif;"> Login  </a>

							<select class="custom-select" style="width:100px;height:30px; margin-left: 30px; font-size: 12px;" id="language" onchange="changeLanguageByButtonClick()">
					  <option value="af">Afrikanns</option>
					  <option value="sq">Albanian</option>
					  <option value="ar">Arabic</option>
					  <option value="hy">Armenian</option>
					  <option value="eu">Basque</option>
					  <option value="bn">Bengali</option>
					  <option value="bg">Bulgarian</option>
					  <option value="ca">Catalan</option>
					  <option value="km">Cambodian</option>
					  <option value="zh-CN">Chinese (Mandarin)</option>
					  <option value="hr">Croatian</option>
					  <option value="cs">Czech</option>
					  <option value="da">Danish</option>
					  <option value="nl">Dutch</option>
					  <option value="en" selected>English</option>
					  <option value="et">Estonian</option>
					  <option value="fj">Fiji</option>
					  <option value="fi">Finnish</option>
					  <option value="fr">French</option>
					  <option value="ka">Georgian</option>
					  <option value="de">German</option>
					  <option value="el">Greek</option>
					  <option value="gu">Gujarati</option>
					  <option value="he">Hebrew</option>
					  <option value="hi">Hindi</option>
					  <option value="hu">Hungarian</option>
					  <option value="is">Icelandic</option>
					  <option value="id">Indonesian</option>
					  <option value="ga">Irish</option>
					  <option value="it">Italian</option>
					  <option value="ja">Japanese</option>
					  <option value="jw">Javanese</option>
					  <option value="ko">Korean</option>
					  <option value="la">Latin</option>
					  <option value="lv">Latvian</option>
					  <option value="lt">Lithuanian</option>
					  <option value="mk">Macedonian</option>
					  <option value="ms">Malay</option>
					  <option value="ml">Malayalam</option>
					  <option value="mt">Maltese</option>
					  <option value="mi">Maori</option>
					  <option value="mr">Marathi</option>
					  <option value="mn">Mongolian</option>
					  <option value="ne">Nepali</option>
					  <option value="no">Norwegian</option>
					  <option value="fa">Persian</option>
					  <option value="pl">Polish</option>
					  <option value="pt">Portuguese</option>
					  <option value="pa">Punjabi</option>
					  <option value="qu">Quechua</option>
					  <option value="ro">Romanian</option>
					  <option value="ru">Russian</option>
					  <option value="sm">Samoan</option>
					  <option value="sr">Serbian</option>
					  <option value="sk">Slovak</option>
					  <option value="sl">Slovenian</option>
					  <option value="es">Spanish</option>
					  <option value="sw">Swahili</option>
					  <option value="sv">Swedish </option>
					  <option value="ta">Tamil</option>
					  <option value="tt">Tatar</option>
					  <option value="te">Telugu</option>
					  <option value="th">Thai</option>
					  <option value="bo">Tibetan</option>
					  <option value="to">Tonga</option>
					  <option value="tr">Turkish</option>
					  <option value="uk">Ukranian</option>
					  <option value="ur">Urdu</option>
					  <option value="uz">Uzbek</option>
					  <option value="vi">Vietnamese</option>
					  <option value="cy">Welsh</option>
					  <option value="xh">Xhosa</option>
					      </select>

					<div id="google_translate_element" style="display:none"></div>
					<script type="text/javascript">

					function googleTranslateElementInit() {
					  new google.translate.TranslateElement({pageLanguage: "en"}, 'google_translate_element');
					}

					function changeLanguageByButtonClick() {
					  var language = document.getElementById("language").value;
					  var selectField = document.querySelector("#google_translate_element select");
					  for(var i=0; i < selectField.children.length; i++){
					    var option = selectField.children[i];
					    // find desired langauge and change the former language of the hidden selection-field 
					    if(option.value==language){
					       selectField.selectedIndex = i;
					       // trigger change event afterwards to make google-lib translate this side
					       selectField.dispatchEvent(new Event('change'));
					       break;
					    }
					  }
					}
					</script>

<script type="text/javascript" src="https://translate.google.com/translate_a/elementa0d8.html?cb=googleTranslateElementInit"></script>
			</div>
							
						
						
					</div>
					<!-- this is the end of the div for the other side  -->

					
				</div>
				
				 
				
			</div>
		</div>
		<!----------------------------------------- end of the first nav --------------------------------------------->

<!-- =============================Wrapper========================================================== -->
     <section class="container-fluid bg-contact-us">
          <div class="row">
            <div class="col-6 abt-us-txt">
              <h2 class="p-20 white">Live Analysis</h2>
            </div>

       
          </div>

          <!-- the body section that contain the text =============== -->
          
        </section>
         <div class="container abt-p-txt">
          <div class="row">

              <div class="col-md-12">
              <!-- TradingView Widget BEGIN -->
                <div class="tradingview-widget-container">
                  <div class="tradingview-widget-container__widget"></div>
                 
                  <script type="text/javascript" src="https://s3.tradingview.com/external-embedding/embed-widget-ticker-tape-2.js" async>
                  {
                  "symbols": [
                    {
                      "proName": "FX_IDC:EURUSD",
                      "title": "EUR/USD"
                    },
                    {
                      "proName": "BITSTAMP:BTCUSD",
                      "title": "BTC/USD"
                    },
                    {
                      "proName": "BITSTAMP:ETHUSD",
                      "title": "ETH/USD"
                    }
                  ],
                  "colorTheme": "dark",
                  "isTransparent": false,
                  "displayMode": "adaptive",
                  "locale": "en"
                }
                  </script>
                </div>
                <!-- TradingView Widget END -->
            </div>
            <div class="col-md-12">

                  <!-- TradingView Widget BEGIN -->
            <div class="tradingview-widget-container">
              <div class="tradingview-widget-container__widget"></div>
              <div class="tradingview-widget-copyright"><a href="https://www.tradingview.com/" rel="noopener" target="_blank"><span class="blue-text">Market Data</span></a> by TradingView</div>
              <script type="text/javascript" src="https://s3.tradingview.com/external-embedding/embed-widget-market-overview.js" async>
              {
              "colorTheme": "dark",
              "dateRange": "12m",
              "showChart": true,
              "locale": "en",
              "largeChartUrl": "",
              "isTransparent": true,
              "width": "100%",
              "height": "500",
              "plotLineColorGrowing": "rgba(25, 118, 210, 1)",
              "plotLineColorFalling": "rgba(25, 118, 210, 1)",
              "gridLineColor": "rgba(42, 46, 57, 1)",
              "scaleFontColor": "rgba(120, 123, 134, 1)",
              "belowLineFillColorGrowing": "rgba(33, 150, 243, 0.12)",
              "belowLineFillColorFalling": "rgba(33, 150, 243, 0.12)",
              "symbolActiveColor": "rgba(33, 150, 243, 0.12)",
              "tabs": [
                {
                  "title": "Indices",
                  "symbols": [
                    {
                      "s": "OANDA:SPX500USD",
                      "d": "S&P 500"
                    },
                    {
                      "s": "OANDA:NAS100USD",
                      "d": "Nasdaq 100"
                    },
                    {
                      "s": "CryptoCOM:DJI",
                      "d": "Dow 30"
                    },
                    {
                      "s": "INDEX:NKY",
                      "d": "Nikkei 225"
                    },
                    {
                      "s": "INDEX:DEU30",
                      "d": "DAX Index"
                    },
                    {
                      "s": "OANDA:UK100GBP",
                      "d": "FTSE 100"
                    }
                  ],
                  "originalTitle": "Indices"
                },
                {
                  "title": "Commodities",
                  "symbols": [
                    {
                      "s": "CME_MINI:ES1!",
                      "d": "E-Mini S&P"
                    },
                    {
                      "s": "CME:6E1!",
                      "d": "Euro"
                    },
                    {
                      "s": "COMEX:GC1!",
                      "d": "Gold"
                    },
                    {
                      "s": "NYMEX:CL1!",
                      "d": "Crude Oil"
                    },
                    {
                      "s": "NYMEX:NG1!",
                      "d": "Natural Gas"
                    },
                    {
                      "s": "CBOT:ZC1!",
                      "d": "Corn"
                    }
                  ],
                  "originalTitle": "Commodities"
                },
                {
                  "title": "Bonds",
                  "symbols": [
                    {
                      "s": "CME:GE1!",
                      "d": "Eurodollar"
                    },
                    {
                      "s": "CBOT:ZB1!",
                      "d": "T-Bond"
                    },
                    {
                      "s": "CBOT:UB1!",
                      "d": "Ultra T-Bond"
                    },
                    {
                      "s": "EUREX:FGBL1!",
                      "d": "Euro Bund"
                    },
                    {
                      "s": "EUREX:FBTP1!",
                      "d": "Euro BTP"
                    },
                    {
                      "s": "EUREX:FGBM1!",
                      "d": "Euro BOBL"
                    }
                  ],
                  "originalTitle": "Bonds"
                },
                {
                  "title": "Crypto",
                  "symbols": [
                    {
                      "s": "FX:EURUSD"
                    },
                    {
                      "s": "FX:GBPUSD"
                    },
                    {
                      "s": "FX:USDJPY"
                    },
                    {
                      "s": "FX:USDCHF"
                    },
                    {
                      "s": "FX:AUDUSD"
                    },
                    {
                      "s": "FX:USDCAD"
                    }
                  ],
                  "originalTitle": "Crypto"
                }
              ]
            }
              </script>
            </div>
            <!-- TradingView Widget END -->

</div>

            </div>
          
            
          </div>
          <div style="padding: 20px;"></div>

 

  <!-- footer -->
     <!-- this is the begining of the footer section  -->

     <footer>

      <div class="container">
      
      
        <div class = "p-20"> </div>
      
      <!-- this is the image section for the logo  -->
      <div class ="footer-logo float-left"> 
        <a class="navbar-brand" href="index.php" style="color:#007bff; font-family: 'Trebuchet MS', sans-serif; font-size: 17px; font-weight: bold !important"> <img src="images/mylogo.png" style="height: 25px; width: 25px" class="brand">&nbsp;ALPHA <span style="color: orange">CHEQUERS<span style="color: #fff; font-family:Arial !important;">™</span></span></a>
      </div>
      <!-- this image is for the secuse ssl  -->
      
       <div class ="footer-logo float-right"> 
        <img src ="images/ssl.png" alt = "Alphachequers">
      </div>
        <div class = "clear-fix"> </div>
      
        <hr>
      
        <div class="row">
      
          <div class = "col-md-3 footer-link">
            <span style="font-family: Arial !important"> <span style="font-weight: bold; font-size: 14px !important; font-family: Arial">About Alphachequers</span>   <br />
              ALPHA CHEQUERS specializes in advanced Bitcoin mining powered by clean energy and smart software strategies. Beyond crypto, we diversify into stocks and commodities: combining technology, innovation, and market expertise to create sustainable growth.
               </div>
      
           <div class = "col-md-6 footer-link footer-list">
           <a href = "index.php"> Home </a> 
           •
           <a href = "about.php"> About us  </a>
           •
           <a href = "Account/Signin/client-register.php"> Sign up  </a>
           •
           <a href = "Account/Signin/access-login.php"> Login  </a>
           •
           <a href = "faq.php"> FAQs  </a>
           •
           <a href = "live-trade.php"> Trade  </a>
          
           <a href = "crypto.php"> Crypto  </a>         
      
           •
           <a href = "contac.php"> Contact us</a>
           •
           <a href = "terms_of_use.php"> Terms of use  </a>
           •
           <a href = "privacy.php"> Privacy Policy  </a>
             <br />
             <br />
             <h6>&nbsp;&nbsp;&nbsp;Contact Information </h6>
               <!--
              <span style = "font-size: 1em">
                <a href ="tel:">
                      <i class="fa fa-phone fa-icons"> </i> +1 4098120358</a>
              </span>
              <br/>
              -->
              
              <span style = "font-size: 1em">
                <a>
                     <i class="fas fa-map-marker-alt"></i> 110 Merrick Way Suite 1, Coral Gables, FL 33134, United States                    </a>
              </span>
              <br/>
              <span style = "font-size: 1em">
                <a href ="mailto:support@alphachequers.com">
                    <i class="fas fa-envelope"></i> support@alphachequers.com                  </a>
              </span>
          </div>
      
            <div class = "col-md-3 footer-link">
          <span style="font-family: Arial !important"> Are you looking for a stable, 
            reliable, guaranteed weekly income? Alphachequers offers a range of options 
            to make the most off your investment. Get involved to discover the power of crypto & stock investment.
        </div>
      
      </div> <!-- end container row -->
     
      
      <br/>
      </div>
     
      
      </footer>

<div class = "last-widget">
  <!-- TradingView Widget BEGIN -->
<div class="tradingview-widget-container" >
<div class="tradingview-widget-container__widget"></div>

<script type="text/javascript" src="https://s3.tradingview.com/external-embedding/embed-widget-ticker-tape.js" async>
{
"symbols": [
{
"proName": "FX_IDC:EURUSD",
"title": "EUR/USD"
},
{
"proName": "BITSTAMP:BTCUSD",
"title": "BTC/USD"
},
{
"proName": "BITSTAMP:ETHUSD",
"title": "ETH/USD"
}
],
"colorTheme": "dark",
"isTransparent": false,
"displayMode": "adaptive",
"locale": "en"
}
</script>
</div>
<!-- TradingView Widget END -->       </div>


<div class="mgm" style="display: none;">
<div class="txt" style="color:black;">Someone from <b></b> just earned <a href="javascript:void(0);" onclick="javascript:void(0);"></a></div>
</div>

<style>
.mgm {
border-radius: 7px;
position: fixed;
z-index: 90;
bottom: 80px;
right: 50px;
background: #00FFE2;
padding: 20px 27px;
box-shadow: 0px 5px 13px 0px rgba(0,0,0,.3);
}
.mgm a {
font-weight: 700;
display: block;
color:#f2d516;
}
.mgm a, .mgm a:active {
transition: all .2s ease;
color:#f2d516;
}
</style>
<script data-cfasync="false" src="cdn-cgi/scripts/5c5dd728/cloudflare-static/email-decode.min.html"></script><script type="text/javascript">
var listCountries = ['Argentina', 'USA', 'Germany', 'France', 'Italy', 'South Korea', 'Australia', 'Norway', 'Canada', 'Argentina', 'Saudi Arabia', 'Mexico', 'Spain', 'Austria', 'Venezuela', 'South Africa', 'Sweden', 'South Korea', 'China', 'Italy', 'Germany', 'United Kingdom', 'Bahrain', 'Greece', 'Cuba', 'Bulgaria', 'Portugal', 'Austria', 'Cyprus', 'Panama', 'Asia', 'Norway', 'Netherlands', 'Switzerland', 'Belgium', 'Israel', 'Cyprus','Spain','Norway'];
var listPlans = ['$2000','$1000','$50000','$15000','$10000','$100000','$20000','$1500','$30000','$40000','$1200','$60000','$3400', '$7000', '$25000', '$25000', '$35000', '$5000','$7000','$45000','$3500','$5000','$12500','$9500'];
interval = Math.floor(Math.random() * (40000 - 8000 + 1) + 8000);
var run = setInterval(request, interval);

function request() {
clearInterval(run);
interval = Math.floor(Math.random() * (40000 - 8000 + 1) + 8000);
var country = listCountries[Math.floor(Math.random() * listCountries.length)];
var plan = listPlans[Math.floor(Math.random() * listPlans.length)];
var msg = 'Someone from <b>' + country + '</b> just earned  <a href="javascript:void(0);" onclick="javascript:void(0);">' + plan + ' .</a>';
$(".mgm .txt").html(msg);
$(".mgm").stop(true).fadeIn(300);
window.setTimeout(function() {
    $(".mgm").stop(true).fadeOut(300);
}, 6000);
run = setInterval(request, interval);
}
</script>


<!-- GetButton.io widget -->
<script type="text/javascript">
    (function () {
        var options = {
            whatsapp: "", // WhatsApp number
            call_to_action: "Message us", // Call to action
            position: "left", // Position may be 'right' or 'left'
        };
        var proto = document.location.protocol, host = "getbutton.io", url = proto + "//static." + host;
        var s = document.createElement('script'); s.type = 'text/javascript'; s.async = true; s.src = url + '/widget-send-button/js/init.js';
        s.onload = function () { WhWidgetSendButton.init(host, proto, options); };
        var x = document.getElementsByTagName('script')[0]; x.parentNode.insertBefore(s, x);
    })();
</script>


<!-- Optional JavaScript -->

<!-- jQuery first, then Popper.js, then Bootstrap JS -->

<script src="js/jquery-ui.js"></script>



<script src="cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.7/umd/popper.min.html" ></script>

<script src="stackpath.bootstrapcdn.com/bootstrap/4.3.1/js/bootstrap.min.js" ></script>

<script type="text/javascript" src="code.jquery.com/jquery-migrate-1.2.1.min.js"></script>

<script type="text/javascript" src="slick/slick.min.js"></script>



<!-- this is the code for the customize slick slider -->

<script type="text/javascript" src="js/custom_slick.js"> </script>

<script type="text/javascript" src="js/range-custom.js"> </script> 

<!-- this is for the counter  -->

<script type="text/javascript" src="js/counter.js"> </script>


<script src="aos/dist/aos.js"></script>
<script>

let scrollRef = 0;

window.addEventListener('scroll', function() {
// increase value up to 10, then refresh AOS
scrollRef <= 10 ? scrollRef++ : AOS.refresh();
});

AOS.init({
 duration: 1200,
});


</script>
<!-- Smartsupp Live Chat script -->
<script src="//code.tidio.co/5dk8g8a2fl4d2pcmaqdiosthk2rbjwjm.js" async></script>


</section> <!-- This is the end of the wrapper section -->


<!-- body section ends here  -->



</body>




</html>